diff Core/DicomFormat/DicomTag.cpp @ 50:a15e90e5d6fc

rename in code
author Sebastien Jodogne <s.jodogne@gmail.com>
date Wed, 05 Sep 2012 15:50:12 +0200
parents f6d12037f886
children c996319e90bc
line wrap: on
line diff
--- a/Core/DicomFormat/DicomTag.cpp	Wed Sep 05 15:38:08 2012 +0200
+++ b/Core/DicomFormat/DicomTag.cpp	Wed Sep 05 15:50:12 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palantir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -20,13 +20,13 @@
 
 #include "DicomTag.h"
 
-#include "../PalantirException.h"
+#include "../PalanthirException.h"
 
 #include <iostream>
 #include <iomanip>
 #include <stdio.h>
 
-namespace Palantir
+namespace Palanthir
 {
   bool DicomTag::operator< (const DicomTag& other) const
   {
@@ -1,5 +1,5 @@
 /**
- * Palantir - A Lightweight, RESTful DICOM Store
+ * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium